==> qt6-base-6.10.0beta2-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6InputSupportPrivate/Qt6InputSupportPrivateDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6InputSupportPrivate_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.10.0
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_InputSupportPrivate_third_party_deps "Libudev\;FALSE\;\;\;;Mtdev\;FALSE\;\;\;;Tslib\;FALSE\;\;\;;Libinput\;FALSE\;\;\;;XKB\;FALSE\;0.5.0\;\;")
set(__qt_InputSupportPrivate_third_party_package_Libudev_provided_targets "PkgConfig::Libudev")
set(__qt_InputSupportPrivate_third_party_package_Mtdev_provided_targets "PkgConfig::Mtdev")
set(__qt_InputSupportPrivate_third_party_package_Tslib_provided_targets "PkgConfig::Tslib")
set(__qt_InputSupportPrivate_third_party_package_Libinput_provided_targets "Libinput::Libinput")
set(__qt_InputSupportPrivate_third_party_package_XKB_provided_targets "XKB::XKB")

_qt_internal_find_third_party_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_third_party_deps)
unset(__qt_InputSupportPrivate_third_party_deps)

# Find Qt tool package.
set(__qt_InputSupportPrivate_tool_deps "")
_qt_internal_find_tool_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_tool_deps)
unset(__qt_InputSupportPrivate_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_InputSupportPrivate_target_deps "Qt6CorePrivate\;6.10.0;Qt6DeviceDiscoverySupportPrivate\;6.10.0;Qt6GuiPrivate\;6.10.0")
set(__qt_InputSupportPrivate_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_target_deps
                                  __qt_InputSupportPrivate_find_dependency_paths)
unset(__qt_InputSupportPrivate_target_deps)
unset(__qt_InputSupportPrivate_find_dependency_paths)

set(_Qt6InputSupportPrivate_MODULE_DEPENDENCIES "CorePrivate;DeviceDiscoverySupportPrivate;GuiPrivate")
set(Qt6InputSupportPrivate_FOUND TRUE)

==> qt6-base-6.11.0beta1-2-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6InputSupportPrivate/Qt6InputSupportPrivateDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

# Make sure Qt6 is found before anything else.
set(Qt6InputSupportPrivate_FOUND FALSE)

if("${_qt_cmake_dir}" STREQUAL "")
    set(_qt_cmake_dir "${QT_TOOLCHAIN_RELOCATABLE_CMAKE_DIR}")
endif()
set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# Don't propagate REQUIRED so we don't immediately FATAL_ERROR, rather let the find_dependency calls
# set _NOT_FOUND_MESSAGE which will be displayed by the includer of the Dependencies file.
set(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED FALSE)

if(NOT Qt6_FOUND)
    find_dependency(Qt6 6.11.0
        PATHS
            ${QT_BUILD_CMAKE_PREFIX_PATH}
            "${CMAKE_CURRENT_LIST_DIR}/.."
            "${_qt_cmake_dir}"
            ${_qt_additional_packages_prefix_paths}
        ${__qt_use_no_default_path_for_qt_packages}
    )
endif()


# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_InputSupportPrivate_third_party_deps "Libudev\;FALSE\;\;\;;Mtdev\;FALSE\;\;\;;Tslib\;FALSE\;\;\;;Libinput\;FALSE\;\;\;;XKB\;FALSE\;0.9.0\;\;")
set(__qt_InputSupportPrivate_third_party_package_Libudev_provided_targets "PkgConfig::Libudev")
set(__qt_InputSupportPrivate_third_party_package_Mtdev_provided_targets "PkgConfig::Mtdev")
set(__qt_InputSupportPrivate_third_party_package_Tslib_provided_targets "PkgConfig::Tslib")
set(__qt_InputSupportPrivate_third_party_package_Libinput_provided_targets "Libinput::Libinput")
set(__qt_InputSupportPrivate_third_party_package_XKB_provided_targets "XKB::XKB")

if(__qt_InputSupportPrivate_third_party_deps)
    _qt_internal_find_third_party_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_third_party_deps)
endif()
unset(__qt_InputSupportPrivate_third_party_deps)

# Find Qt tool package.
set(__qt_InputSupportPrivate_tool_deps "")
if(__qt_InputSupportPrivate_tool_deps)
    _qt_internal_find_tool_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_tool_deps)
endif()
unset(__qt_InputSupportPrivate_tool_deps)

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_InputSupportPrivate_target_deps "Qt6CorePrivate\;6.11.0;Qt6DeviceDiscoverySupportPrivate\;6.11.0;Qt6GuiPrivate\;6.11.0")
set(__qt_InputSupportPrivate_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/.." "${_qt_cmake_dir}")
if(__qt_InputSupportPrivate_target_deps)
    _qt_internal_find_qt_dependencies("InputSupportPrivate" __qt_InputSupportPrivate_target_deps
                                      __qt_InputSupportPrivate_find_dependency_paths)
endif()
unset(__qt_InputSupportPrivate_target_deps)
unset(__qt_InputSupportPrivate_find_dependency_paths)

set(_Qt6InputSupportPrivate_MODULE_DEPENDENCIES "CorePrivate;DeviceDiscoverySupportPrivate;GuiPrivate")
set(Qt6InputSupportPrivate_FOUND TRUE)
